.. _changelog:

Changelog
=========

These are the notable changes for each django-ldap-sync release. For
additional detail, read the complete `commit history`_.

**django-ldap-sync 0.1.1**
   * Fix exception with AD internal referrals

**django-ldap-sync 0.1.0**
   * Initial release

.. _commit history: https://github.com/jbittel/django-ldap-sync/commits/
